#
# spec file for package extension-manager
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         appname com.mattjakeman.ExtensionManager
Name:           extension-manager
Version:        0.5.1
Release:        2.1
Summary:        A utility for browsing and installing GNOME Shell Extensions
License:        GPL-3.0-only
URL:            https://github.com/mjakeman/extension-manager
Source:         %{url}/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  desktop-file-utils
BuildRequires:  gcc-c++
BuildRequires:  libbacktrace-devel
BuildRequires:  meson
BuildRequires:  pkgconfig(blueprint-compiler)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libadwaita-1)
BuildRequires:  pkgconfig(libsoup-3.0)
BuildRequires:  pkgconfig(text-engine-0.1)

%description
A native tool for browsing, installing, and managing GNOME Shell Extensions.

%lang_package

%prep
%autosetup

%build
export CFLAGS="$optflags -Wno-error -Wno-unused-variable -Wno-unused-parameter -Wno-incompatible-pointer-types -Wno-return-mismatch -Wno-int-conversion"
%meson
%meson_build

%install
%meson_install

%find_lang %{name}

%files
%license COPYING
%doc README.md
%{_bindir}/%{name}
%{_datadir}/applications/%{appname}.desktop
%{_datadir}/glib-2.0/schemas/%{appname}.gschema.xml
%{_iconsdir}/hicolor/scalable/apps/%{appname}.svg
%{_iconsdir}/hicolor/symbolic/apps/%{appname}-symbolic.svg
%{_datadir}/metainfo/%{appname}.metainfo.xml

%files lang -f %{name}.lang

%changelog
* Sun Aug 25 2024 Richard Rahl <rrahl0@opensuse.org>
- fix gcc14 by using "-Wno-error -Wno-unused-variable -Wno-unused-parameter
  - Wno-incompatible-pointer-types -Wno-return-mismatch -Wno-int-conversion"
* Thu May  2 2024 Richard Rahl <rrahl0@disroot.org>
- update to 0.5.1:
  * Add null checks for version parsing
  * backtrace: Collate 'null' messages
  * Use AdwPreferences* widgets
  * Fix crash on close while loading
- update to 0.5.0:
  * New widgets, better resizing, cleaner look
  * Compatibility with GNOME 46
  * Display extension icons and statistics
  * Search is more reliable
* Fri Feb 23 2024 Richard Rahl <rrahl0@proton.me>
- fix spec for Factory
* Fri Feb 23 2024 Richard Rahl <rrahl0@proton.me>
- clean up spec file
* Thu Nov 16 2023 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.4.3:
  * Translations update.
* Wed Jun 21 2023 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.4.2:
  * upgrade-assistant: don't scroll horizontally on results.
  * misc: Tweak app icon and optimize symbolics.
  * Translations update.
* Fri May  5 2023 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.4.1:
  * Translations update.
* Thu Mar 30 2023 Dead Mozay <dead_mozay@opensuse.org>
- Initial package.
